@@ -3,13 +3,14 @@
 set -ex
 
 GATE_DEST=$BASE/new
+DEVSTACK_PATH=$GATE_DEST/devstack
 
 testenv=${2:-"apiv2"}
 
 if [ "$1" = "lbaasv1" ]; then
     testenv="apiv1"
 elif [ "$1" = "lbaasv2" ]; then
-    if [ "$2" = "api" ]; then
+    if [ "$2" = "healthmonitor" ] || [ "$2" = "listener" ] || [ "$2" = "loadbalancer" ] || [ "$2" = "member" ] || [ "$2" = "minimal" ] || [ "$2" = "pool" ]; then
         testenv="apiv2"
     elif [ "$2" = "scenario" ]; then
           testenv="scenario"
@@ -20,7 +21,6 @@ export DEVSTACK_LOCAL_CONFIG+="
 enable_plugin neutron-lbaas https://git.openstack.org/openstack/neutron-lbaas
 enable_plugin barbican https://git.openstack.org/openstack/barbican
 enable_plugin octavia https://git.openstack.org/openstack/octavia
-IMAGE_URLS+=\",http://g8de985af226d635b09bbb525b05dc4af.cdn.hpcloudsvc.com/amphora/amphora-x64-haproxy.qcow2\"
 "
 
 if [ "$testenv" != "apiv1" ]; then
@@ -31,8 +31,23 @@ if [ "$testenv" != "apiv1" ]; then
   ENABLED_SERVICES+=",-s-account,-s-container,-s-object,-s-proxy"
   ENABLED_SERVICES+=",octavia,o-cw,o-hk,o-hm,o-api"
   export ENABLED_SERVICES
-  VOLUME_BACKING_FILE_SIZE=24G
-  export VOLUME_BACKING_FILE_SIZE
+  DISABLE_AMP_IMAGE_BUILD=True
+  export DISABLE_AMP_IMAGE_BUILD
+fi
+
+if [ "$testenv" = "apiv2" ]; then
+   cat > $DEVSTACK_PATH/local.conf <<EOF
+[[post-config|/etc/octavia/octavia.conf]]
+[DEFAULT]
+debug = True
+
+[controller_worker]
+amphora_driver = amphora_noop_driver
+compute_driver = compute_noop_driver
+network_driver = network_noop_driver
+
+EOF
+
 fi
 
 $GATE_DEST/devstack-gate/devstack-vm-gate.sh
