@@ -14,6 +14,7 @@
 
 from oslo_log import log as logging
 from tempest_lib.common.utils import data_utils
+from tempest_lib import exceptions as ex
 
 from neutron_lbaas.tests.tempest.lib import config
 from neutron_lbaas.tests.tempest.lib import test
@@ -84,13 +85,12 @@ class LoadBalancersTestJSON(base.BaseAdminTestCase):
 
     @test.attr(type='smoke')
     def test_create_load_balancer_empty_tenant_id_field(self):
-        """Test create load balancer with empty tenant_id field"""
-        load_balancer = self.load_balancers_client.create_load_balancer(
-            vip_subnet_id=self.subnet['id'],
-            tenant_id="")
-        self.assertEqual(load_balancer.get('tenant_id'), "")
-        self._wait_for_load_balancer_status(load_balancer['id'])
-        self._delete_load_balancer(load_balancer['id'])
+        """Test create load balancer with empty tenant_id field should fail"""
+        self.assertRaises(ex.BadRequest,
+                          self.load_balancers_client.create_load_balancer,
+                          vip_subnet_id=self.subnet['id'],
+                          wait=False,
+                          tenant_id="")
 
     @test.attr(type='smoke')
     def test_create_load_balancer_for_another_tenant(self):
