@@ -19,6 +19,14 @@ neutron_installed=$(echo "import neutron" | python 2>/dev/null ; echo $?)
 
 set -e
 
+CONSTRAINTS_FILE=$1
+shift
+
+install_cmd="pip install"
+if [ $CONSTRAINTS_FILE != "unconstrained" ]; then
+    install_cmd="$install_cmd -c$CONSTRAINTS_FILE"
+fi
+
 if [ $neutron_installed -eq 0 ]; then
     echo "ALREADY INSTALLED" > /tmp/tox_install.txt
     echo "Neutron already installed; using existing package"
@@ -33,12 +41,12 @@ elif [ -x "$ZUUL_CLONER" ]; then
         git://git.openstack.org \
         openstack/neutron
     cd openstack/neutron
-    pip install -e .
+    $install_cmd -e .
     cd "$cwd"
 else
     echo "PIP HARDCODE" > /tmp/tox_install.txt
-    pip install -U -egit+https://git.openstack.org/openstack/neutron@$BRANCH_NAME#egg=neutron
+    $install_cmd -U -egit+https://git.openstack.org/openstack/neutron@$BRANCH_NAME#egg=neutron
 fi
 
-pip install -U $*
+$install_cmd -U $*
 exit $?
